// src/context/months.tsx
import { createStoreContext } from "@leight/context-client";
import {
  DateTime,
  monthsOf
} from "@leight/i18n";
import { jsx } from "react/jsx-runtime";
var {
  Provider: MonthsStoreProvider,
  useState: useMonths
} = createStoreContext({
  state: ({ state }) => (set) => ({
    monthsOf(input) {
      set({
        months: monthsOf({ input })
      });
    },
    today() {
      set({
        months: monthsOf({ input: DateTime.now() })
      });
    },
    prevYear() {
      set(({ months: { input } }) => ({
        months: monthsOf({ input: input.minus({ year: 1 }) })
      }));
    },
    nextYear() {
      set(({ months: { input } }) => ({
        months: monthsOf({ input: input.plus({ year: 1 }) })
      }));
    },
    ...state
  }),
  name: "MonthsContext",
  hint: "Add MonthsProvider."
});
var MonthsProvider = ({ input, ...props }) => {
  return /* @__PURE__ */ jsx(
    MonthsStoreProvider,
    {
      state: {
        months: monthsOf({ input })
      },
      ...props
    }
  );
};

// src/context/weeks.tsx
import { createStoreContext as createStoreContext2 } from "@leight/context-client";
import {
  DateTime as DateTime2,
  weeksOf
} from "@leight/i18n";
import { jsx as jsx2 } from "react/jsx-runtime";
var {
  Provider: WeeksStoreProvider,
  useState: useWeeks
} = createStoreContext2({
  state: ({ state }) => (set) => ({
    weeksOf(input) {
      set({
        weeks: weeksOf({ input })
      });
    },
    today() {
      set({
        weeks: weeksOf({ input: DateTime2.now() })
      });
    },
    prevMonth() {
      set(({ weeks: { input } }) => ({
        weeks: weeksOf({ input: input.minus({ month: 1 }) })
      }));
    },
    nextMonth() {
      set(({ weeks: { input } }) => ({
        weeks: weeksOf({ input: input.plus({ month: 1 }) })
      }));
    },
    prevYear() {
      set(({ weeks: { input } }) => ({
        weeks: weeksOf({ input: input.minus({ year: 1 }) })
      }));
    },
    nextYear() {
      set(({ weeks: { input } }) => ({
        weeks: weeksOf({ input: input.plus({ year: 1 }) })
      }));
    },
    ...state
  }),
  name: "WeeksContext",
  hint: "Add WeeksProvider."
});
var WeeksProvider = ({ input, ...props }) => {
  return /* @__PURE__ */ jsx2(
    WeeksStoreProvider,
    {
      state: {
        weeks: weeksOf({ input })
      },
      ...props
    }
  );
};

// src/context/years.tsx
import { createStoreContext as createStoreContext3 } from "@leight/context-client";
import {
  DateTime as DateTime3,
  yearsOf
} from "@leight/i18n";
import { jsx as jsx3 } from "react/jsx-runtime";
var {
  Provider: YearsStoreProvider,
  useState: useYears
} = createStoreContext3({
  state: ({ state }) => (set) => ({
    yearsOf(input) {
      set({
        years: yearsOf({ input })
      });
    },
    today() {
      set({
        years: yearsOf({ input: DateTime3.now() })
      });
    },
    prevYear() {
      set(({ years: { input } }) => ({
        years: yearsOf({ input: input.minus({ year: 1 }) })
      }));
    },
    nextYear() {
      set(({ years: { input } }) => ({
        years: yearsOf({ input: input.plus({ year: 1 }) })
      }));
    },
    prevYears() {
      set(({ years: { count, input } }) => ({
        years: yearsOf({ input: input.minus({ year: count }) })
      }));
    },
    nextYears() {
      set(({ years: { count, input } }) => ({
        years: yearsOf({ input: input.plus({ year: count }) })
      }));
    },
    ...state
  }),
  name: "YearsContext",
  hint: "Add YearsProvider."
});
var YearsProvider = ({ input, ...props }) => {
  return /* @__PURE__ */ jsx3(
    YearsStoreProvider,
    {
      state: {
        years: yearsOf({ input })
      },
      ...props
    }
  );
};

// src/context/index.tsx
import { jsx as jsx4 } from "react/jsx-runtime";
var CalendarProvider = ({ children, input }) => {
  return /* @__PURE__ */ jsx4(
    YearsProvider,
    {
      input,
      children: /* @__PURE__ */ jsx4(
        MonthsProvider,
        {
          input,
          children: /* @__PURE__ */ jsx4(
            WeeksProvider,
            {
              input,
              children
            }
          )
        }
      )
    }
  );
};

// src/inline/DateRageInline.tsx
import { DateInline } from "@leight/i18n-client";
import { Breadcrumbs } from "@mantine/core";
import { jsx as jsx5, jsxs } from "react/jsx-runtime";
var DateRageInline = ({
  start,
  end,
  startOptions = { day: "numeric", month: "numeric" },
  endOptions,
  ...props
}) => {
  return /* @__PURE__ */ jsxs(
    Breadcrumbs,
    {
      separator: "\u2192",
      className: "secondary",
      ...props,
      children: [
        /* @__PURE__ */ jsx5(
          DateInline,
          {
            input: start.toJSDate(),
            options: startOptions
          }
        ),
        /* @__PURE__ */ jsx5(
          DateInline,
          {
            input: end.toJSDate(),
            options: endOptions
          }
        )
      ]
    }
  );
};

// src/ui/Calendar.tsx
import { DateInline as DateInline5 } from "@leight/i18n-client";
import {
  ActionIcon as ActionIcon2,
  Box,
  Button as Button4,
  Overlay
} from "@mantine/core";
import {
  IconCalendarSearch,
  IconX
} from "@tabler/icons-react";
import {
  useState as useState2
} from "react";

// src/ui/Months.tsx
import {
  DateTime as DateTime4
} from "@leight/i18n";
import { DateInline as DateInline2 } from "@leight/i18n-client";
import { classNames as classNames2 } from "@leight/utils-client";
import {
  Button,
  Grid as Grid2,
  Group,
  Text
} from "@mantine/core";
import {
  IconChevronLeft,
  IconChevronRight
} from "@tabler/icons-react";

// src/ui/CalendarShell.tsx
import { isCallable } from "@leight/utils";
import { classNames } from "@leight/utils-client";
import {
  Container,
  createStyles,
  Grid
} from "@mantine/core";
import { jsx as jsx6, jsxs as jsxs2 } from "react/jsx-runtime";
var useStyles = createStyles((theme) => ({
  calendar: {
    userSelect: "none"
  },
  calendarGrid: {
    border: "1px solid",
    borderColor: theme.colors["gray"][4],
    borderBottom: "none",
    borderRight: "none",
    "&:last-child": {
      border: "1px solid",
      borderColor: theme.colors["gray"][4],
      borderRight: "none"
    }
  },
  controlsGrid: {
    "& > div:last-child": {
      borderRight: "1px solid",
      borderColor: theme.colors["gray"][4]
    }
  },
  controls: {
    display: "flex",
    flex: "1 1 auto",
    alignItems: "center"
  },
  controlsLeft: {},
  controlsMiddle: {
    justifyContent: "center"
  },
  controlsRight: {
    justifyContent: "end"
  },
  controlsPrefix: {},
  controlsSuffix: {},
  header: {
    backgroundColor: theme.colors["gray"][0],
    fontWeight: "bold",
    height: "3em",
    display: "flex",
    flex: "1 1 auto",
    justifyContent: "center",
    alignItems: "center"
  },
  cell: {
    height: "6em",
    padding: "0.4em 0.6em",
    "&:hover": {
      backgroundColor: theme.colors["gray"][0]
    }
  },
  monthCell: {
    display: "flex",
    flex: "1 1 auto",
    justifyContent: "center",
    alignItems: "center"
  },
  yearCell: {
    display: "flex",
    flex: "1 1 auto",
    justifyContent: "center",
    alignItems: "center"
  },
  row: {
    "& > div": {
      borderRight: "1px solid",
      borderColor: theme.colors["gray"][4]
    }
  },
  currentMonth: {
    fontWeight: "bold",
    backgroundColor: theme.colors["gray"][1]
  },
  currentYear: {
    fontWeight: "bold",
    backgroundColor: theme.colors["gray"][1]
  },
  currentWeek: {},
  currentDay: {
    backgroundColor: theme.colors["gray"][2]
  },
  inRange: {
    fontWeight: "bold"
  },
  outOfRange: {
    backgroundColor: theme.colors["gray"][0]
  }
}));
var renderComponent = (component, props) => isCallable(component) ? component(props) : component;
var CalendarShell = ({
  withControls = true,
  controlsTopLeft,
  controlsTopMiddle,
  controlsTopRight,
  controlsBottomLeft,
  controlsBottomMiddle,
  controlsBottomRight,
  children,
  ...props
}) => {
  const { classes } = useStyles();
  const controlColumnCount = 18;
  const controlWidth = 7;
  const renderProps = {
    classes
  };
  return /* @__PURE__ */ jsxs2(
    Container,
    {
      className: classes.calendar,
      ...props,
      children: [
        withControls && /* @__PURE__ */ jsxs2(
          Grid,
          {
            columns: controlColumnCount,
            className: classNames(
              classes.calendarGrid,
              classes.controlsGrid,
              classes.controlsPrefix
            ),
            m: 0,
            children: [
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsLeft
                  ),
                  children: renderComponent(controlsTopLeft, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlColumnCount - controlWidth * 2,
                  className: classNames(
                    classes.controls,
                    classes.controlsMiddle
                  ),
                  children: renderComponent(controlsTopMiddle, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsRight
                  ),
                  children: renderComponent(controlsTopRight, renderProps)
                }
              )
            ]
          }
        ),
        renderComponent(children, renderProps),
        withControls && (controlsBottomLeft || controlsBottomMiddle || controlsBottomRight) && /* @__PURE__ */ jsxs2(
          Grid,
          {
            columns: controlColumnCount,
            className: classNames(
              classes.calendarGrid,
              classes.controlsGrid,
              classes.controlsSuffix
            ),
            m: 0,
            children: [
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsLeft
                  ),
                  children: renderComponent(controlsBottomLeft, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlColumnCount - controlWidth * 2,
                  className: classNames(
                    classes.controls,
                    classes.controlsMiddle
                  ),
                  children: renderComponent(controlsBottomMiddle, renderProps)
                }
              ),
              /* @__PURE__ */ jsx6(
                Grid.Col,
                {
                  span: controlWidth,
                  className: classNames(
                    classes.controls,
                    classes.controlsRight
                  ),
                  children: renderComponent(controlsBottomRight, renderProps)
                }
              )
            ]
          }
        )
      ]
    }
  );
};

// src/ui/Months.tsx
import { Fragment, jsx as jsx7, jsxs as jsxs3 } from "react/jsx-runtime";
var Months = ({
  children,
  onClick,
  ...props
}) => {
  const { months: { months, isCurrent, input }, today, prevYear, nextYear } = useMonths();
  const columnCount = 4;
  const rowCount = months.length / columnCount;
  return /* @__PURE__ */ jsx7(
    CalendarShell,
    {
      controlsTopLeft: /* @__PURE__ */ jsx7(Group, { spacing: "sm", children: /* @__PURE__ */ jsx7(Button.Group, { children: /* @__PURE__ */ jsx7(
        Button,
        {
          size: "sm",
          variant: "subtle",
          onClick: () => prevYear(),
          leftIcon: /* @__PURE__ */ jsx7(IconChevronLeft, {}),
          children: /* @__PURE__ */ jsx7(
            DateInline2,
            {
              input: input.minus({ year: 1 }).toJSDate(),
              options: { year: "numeric" }
            }
          )
        }
      ) }) }),
      controlsTopMiddle: /* @__PURE__ */ jsx7(Group, { spacing: "sm", children: /* @__PURE__ */ jsx7(
        Button,
        {
          variant: "subtle",
          onClick: () => today(),
          disabled: isCurrent,
          children: /* @__PURE__ */ jsx7(Text, { c: "dimmed", children: isCurrent ? /* @__PURE__ */ jsx7(DateInline2, { input: DateTime4.now().toJSDate(), options: { day: "numeric", month: "long", year: "numeric" } }) : /* @__PURE__ */ jsx7(DateInline2, { input: input.toJSDate(), options: { year: "numeric" } }) })
        }
      ) }),
      controlsTopRight: /* @__PURE__ */ jsx7(Group, { spacing: "sm", children: /* @__PURE__ */ jsx7(Button.Group, { children: /* @__PURE__ */ jsx7(
        Button,
        {
          size: "sm",
          variant: "subtle",
          onClick: () => nextYear(),
          rightIcon: /* @__PURE__ */ jsx7(IconChevronRight, {}),
          children: /* @__PURE__ */ jsx7(
            DateInline2,
            {
              input: input.plus({ year: 1 }).toJSDate(),
              options: { year: "numeric" }
            }
          )
        }
      ) }) }),
      ...props,
      children: ({ classes }) => /* @__PURE__ */ jsxs3(Fragment, { children: [
        Array.from({ length: rowCount }, (_, row) => /* @__PURE__ */ jsx7(
          Grid2,
          {
            columns: columnCount,
            className: classNames2(
              classes.calendarGrid,
              classes.row
            ),
            m: 0,
            children: Array.from({ length: columnCount }, (_2, column) => {
              const month = months[row * columnCount + column];
              if (!month) {
                return null;
              }
              return /* @__PURE__ */ jsx7(
                Grid2.Col,
                {
                  span: 1,
                  className: classNames2(
                    classes.cell,
                    classes.monthCell,
                    month.isCurrent ? classes.currentMonth : void 0
                  ),
                  style: onClick ? { cursor: "pointer" } : void 0,
                  onClick: () => onClick?.({ month }),
                  children: month.name
                },
                month.id
              );
            })
          },
          `month${row}`
        )),
        children
      ] })
    }
  );
};

// src/ui/Weeks.tsx
import {
  DateTime as DateTime5
} from "@leight/i18n";
import { DateInline as DateInline3 } from "@leight/i18n-client";
import { classNames as classNames3 } from "@leight/utils-client";
import {
  ActionIcon,
  Button as Button2,
  Grid as Grid3,
  Group as Group2,
  Text as Text2
} from "@mantine/core";
import {
  IconCalendarEvent,
  IconChevronLeft as IconChevronLeft2,
  IconChevronRight as IconChevronRight2,
  IconChevronsLeft,
  IconChevronsRight
} from "@tabler/icons-react";
import {
  useState
} from "react";
import { Fragment as Fragment2, jsx as jsx8, jsxs as jsxs4 } from "react/jsx-runtime";
var Weeks = ({
  onClick,
  highlightToday = true,
  defaultWithWeekNo = false,
  weekCountSize = 2,
  columnSize = 3,
  children,
  ...props
}) => {
  const {
    nextMonth,
    prevMonth,
    prevYear,
    nextYear,
    today,
    weeks: {
      weeks,
      days,
      start,
      isCurrent
    }
  } = useWeeks();
  const [withWeeks, setWithWeeks] = useState(defaultWithWeekNo);
  const columnCount = days.length * columnSize + (withWeeks ? weekCountSize : 0);
  return /* @__PURE__ */ jsx8(
    CalendarShell,
    {
      controlsTopLeft: /* @__PURE__ */ jsx8(Group2, { spacing: "sm", children: /* @__PURE__ */ jsxs4(Button2.Group, { children: [
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => prevMonth(),
            leftIcon: /* @__PURE__ */ jsx8(IconChevronLeft2, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                input: start.minus({ month: 1 }).toJSDate(),
                options: { month: "long" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => prevYear(),
            leftIcon: /* @__PURE__ */ jsx8(IconChevronsLeft, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                input: start.minus({ year: 1 }).toJSDate(),
                options: { year: "numeric" }
              }
            )
          }
        )
      ] }) }),
      controlsTopMiddle: /* @__PURE__ */ jsx8(Group2, { spacing: "sm", children: /* @__PURE__ */ jsx8(
        Button2,
        {
          variant: "subtle",
          onClick: () => today(),
          disabled: isCurrent,
          children: /* @__PURE__ */ jsx8(Text2, { c: "dimmed", children: isCurrent ? /* @__PURE__ */ jsx8(DateInline3, { input: DateTime5.now().toJSDate(), options: { day: "numeric", month: "long", year: "numeric" } }) : /* @__PURE__ */ jsx8(DateInline3, { input: start.toJSDate(), options: { month: "long", year: "numeric" } }) })
        }
      ) }),
      controlsTopRight: /* @__PURE__ */ jsx8(Group2, { spacing: "sm", children: /* @__PURE__ */ jsxs4(Button2.Group, { children: [
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => nextYear(),
            rightIcon: /* @__PURE__ */ jsx8(IconChevronsRight, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                input: start.plus({ year: 1 }).toJSDate(),
                options: { year: "numeric" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx8(
          Button2,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => nextMonth(),
            rightIcon: /* @__PURE__ */ jsx8(IconChevronRight2, {}),
            children: /* @__PURE__ */ jsx8(
              DateInline3,
              {
                input: start.plus({ month: 1 }).toJSDate(),
                options: { month: "long" }
              }
            )
          }
        )
      ] }) }),
      controlsBottomLeft: /* @__PURE__ */ jsx8(
        ActionIcon,
        {
          variant: "subtle",
          onClick: () => setWithWeeks((weeks2) => !weeks2),
          children: /* @__PURE__ */ jsx8(IconCalendarEvent, {})
        }
      ),
      ...props,
      children: ({ classes }) => /* @__PURE__ */ jsxs4(Fragment2, { children: [
        /* @__PURE__ */ jsxs4(
          Grid3,
          {
            columns: columnCount,
            className: classNames3(
              classes.calendarGrid,
              classes.row
            ),
            m: 0,
            children: [
              withWeeks && /* @__PURE__ */ jsx8(
                Grid3.Col,
                {
                  span: weekCountSize,
                  className: classes.header,
                  children: /* @__PURE__ */ jsx8(ActionIcon, { variant: "light", children: /* @__PURE__ */ jsx8(IconCalendarEvent, {}) })
                }
              ),
              days.map((day) => /* @__PURE__ */ jsx8(
                Grid3.Col,
                {
                  span: columnSize,
                  className: classes.header,
                  children: day
                },
                `day-${day}`
              ))
            ]
          }
        ),
        weeks.map(({ days: days2, number, isCurrent: isCurrent2, id }) => /* @__PURE__ */ jsxs4(
          Grid3,
          {
            columns: columnCount,
            className: classNames3(
              classes.calendarGrid,
              classes.row,
              isCurrent2 ? classes.currentWeek : void 0
            ),
            m: 0,
            children: [
              withWeeks && /* @__PURE__ */ jsxs4(
                Grid3.Col,
                {
                  span: weekCountSize,
                  children: [
                    number,
                    "."
                  ]
                }
              ),
              days2.map((day) => /* @__PURE__ */ jsx8(
                Grid3.Col,
                {
                  span: columnSize,
                  className: classNames3(
                    classes.cell,
                    day.isCurrent && highlightToday ? classes.currentDay : void 0,
                    day.isOutOfRange ? classes.outOfRange : classes.inRange
                  ),
                  style: onClick ? { cursor: "pointer" } : void 0,
                  onClick: () => onClick?.({ day }),
                  children: /* @__PURE__ */ jsx8(
                    "div",
                    {
                      style: {
                        textAlign: "right"
                      },
                      children: day.day.day
                    }
                  )
                },
                day.id
              ))
            ]
          },
          id
        )),
        children
      ] })
    }
  );
};

// src/ui/Years.tsx
import { DateInline as DateInline4 } from "@leight/i18n-client";
import { classNames as classNames4 } from "@leight/utils-client";
import {
  Button as Button3,
  Grid as Grid4,
  Group as Group3,
  Text as Text3
} from "@mantine/core";
import {
  IconChevronLeft as IconChevronLeft3,
  IconChevronRight as IconChevronRight3,
  IconChevronsLeft as IconChevronsLeft2,
  IconChevronsRight as IconChevronsRight2
} from "@tabler/icons-react";
import { Fragment as Fragment3, jsx as jsx9, jsxs as jsxs5 } from "react/jsx-runtime";
var Years = ({
  children,
  onClick,
  ...props
}) => {
  const {
    years: {
      years,
      isCurrent,
      start,
      end,
      columns,
      rows,
      count
    },
    today,
    prevYear,
    nextYear,
    prevYears,
    nextYears
  } = useYears();
  return /* @__PURE__ */ jsx9(
    CalendarShell,
    {
      controlsTopLeft: /* @__PURE__ */ jsx9(Group3, { spacing: "sm", children: /* @__PURE__ */ jsxs5(Button3.Group, { children: [
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => prevYears(),
            leftIcon: /* @__PURE__ */ jsx9(IconChevronsLeft2, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                input: start.minus({ year: count }).toJSDate(),
                options: { year: "numeric" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => prevYear(),
            leftIcon: /* @__PURE__ */ jsx9(IconChevronLeft3, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                input: start.minus({ year: 1 }).toJSDate(),
                options: { year: "numeric" }
              }
            )
          }
        )
      ] }) }),
      controlsTopMiddle: /* @__PURE__ */ jsx9(Group3, { spacing: "sm", children: /* @__PURE__ */ jsx9(
        Button3,
        {
          variant: "subtle",
          onClick: () => today(),
          disabled: isCurrent,
          children: /* @__PURE__ */ jsx9(Text3, { c: "dimmed", children: /* @__PURE__ */ jsx9(
            DateRageInline,
            {
              start,
              end,
              startOptions: { year: "numeric" },
              endOptions: { year: "numeric" }
            }
          ) })
        }
      ) }),
      controlsTopRight: /* @__PURE__ */ jsx9(Group3, { spacing: "sm", children: /* @__PURE__ */ jsxs5(Button3.Group, { children: [
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => nextYear(),
            rightIcon: /* @__PURE__ */ jsx9(IconChevronRight3, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                input: end.plus({ year: 1 }).toJSDate(),
                options: { year: "numeric" }
              }
            )
          }
        ),
        /* @__PURE__ */ jsx9(
          Button3,
          {
            size: "sm",
            variant: "subtle",
            onClick: () => nextYears(),
            leftIcon: /* @__PURE__ */ jsx9(IconChevronsRight2, {}),
            children: /* @__PURE__ */ jsx9(
              DateInline4,
              {
                input: end.plus({ year: count }).toJSDate(),
                options: { year: "numeric" }
              }
            )
          }
        )
      ] }) }),
      ...props,
      children: ({ classes }) => /* @__PURE__ */ jsxs5(Fragment3, { children: [
        Array.from({ length: rows }, (_, row) => /* @__PURE__ */ jsx9(
          Grid4,
          {
            columns,
            className: classNames4(
              classes.calendarGrid,
              classes.row
            ),
            m: 0,
            children: Array.from({ length: columns }, (_2, column) => {
              const year = years[row * columns + column];
              if (!year) {
                return null;
              }
              return /* @__PURE__ */ jsx9(
                Grid4.Col,
                {
                  span: 1,
                  className: classNames4(
                    classes.cell,
                    classes.yearCell,
                    year.isCurrent ? classes.currentYear : void 0
                  ),
                  style: onClick ? { cursor: "pointer" } : void 0,
                  onClick: () => onClick?.({ year }),
                  children: year.name
                },
                year.id
              );
            })
          },
          `year${row}`
        )),
        children
      ] })
    }
  );
};

// src/ui/Calendar.tsx
import { jsx as jsx10, jsxs as jsxs6 } from "react/jsx-runtime";
var Calendar = ({ input, ...props }) => {
  return /* @__PURE__ */ jsx10(
    CalendarProvider,
    {
      input,
      children: /* @__PURE__ */ jsx10(CalendarInternal, { ...props })
    }
  );
};
var CalendarInternal = ({ withControls, onClick }) => {
  const { weeksOf: weeksOf2, weeks } = useWeeks(({ weeksOf: weeksOf3, weeks: weeks2 }) => ({ weeksOf: weeksOf3, weeks: weeks2 }));
  const { monthsOf: monthsOf2 } = useMonths(({ monthsOf: monthsOf3 }) => ({ monthsOf: monthsOf3 }));
  const { yearsOf: yearsOf2 } = useYears(({ yearsOf: yearsOf3 }) => ({ yearsOf: yearsOf3 }));
  const [selectMonth, setSelectMonth] = useState2(false);
  const [selectYear, setSelectYear] = useState2(false);
  return /* @__PURE__ */ jsx10(Box, { pos: "relative", children: /* @__PURE__ */ jsxs6(
    Weeks,
    {
      onClick,
      withControls,
      controlsBottomMiddle: /* @__PURE__ */ jsxs6(Button4.Group, { children: [
        /* @__PURE__ */ jsx10(
          Button4,
          {
            variant: "subtle",
            onClick: () => {
              setSelectMonth(true);
              monthsOf2(weeks.input);
            },
            leftIcon: /* @__PURE__ */ jsx10(IconCalendarSearch, {}),
            children: /* @__PURE__ */ jsx10(DateInline5, { input: weeks.input.toJSDate(), options: { month: "long" } })
          }
        ),
        /* @__PURE__ */ jsx10(
          Button4,
          {
            variant: "subtle",
            onClick: () => {
              setSelectYear(true);
              yearsOf2(weeks.input);
            },
            leftIcon: /* @__PURE__ */ jsx10(IconCalendarSearch, {}),
            children: /* @__PURE__ */ jsx10(DateInline5, { input: weeks.input.toJSDate(), options: { year: "numeric" } })
          }
        )
      ] }),
      children: [
        selectMonth && /* @__PURE__ */ jsx10(Overlay, { color: "#FFF", opacity: 1, children: /* @__PURE__ */ jsx10(
          Months,
          {
            onClick: ({ month: { month } }) => {
              weeksOf2(month);
              setSelectMonth(false);
            },
            controlsBottomMiddle: /* @__PURE__ */ jsx10(
              ActionIcon2,
              {
                variant: "subtle",
                onClick: () => setSelectMonth(false),
                children: /* @__PURE__ */ jsx10(IconX, {})
              }
            )
          }
        ) }),
        selectYear && /* @__PURE__ */ jsx10(Overlay, { color: "#FFF", opacity: 1, children: /* @__PURE__ */ jsx10(
          Years,
          {
            onClick: ({ year: { year } }) => {
              weeksOf2(year);
              setSelectYear(false);
            },
            controlsBottomMiddle: /* @__PURE__ */ jsx10(
              ActionIcon2,
              {
                variant: "subtle",
                onClick: () => setSelectYear(false),
                children: /* @__PURE__ */ jsx10(IconX, {})
              }
            )
          }
        ) })
      ]
    }
  ) });
};
export {
  Calendar,
  CalendarProvider,
  CalendarShell,
  DateRageInline,
  Months,
  MonthsProvider,
  MonthsStoreProvider,
  Weeks,
  WeeksProvider,
  WeeksStoreProvider,
  Years,
  YearsProvider,
  YearsStoreProvider,
  useMonths,
  useWeeks,
  useYears
};
//# sourceMappingURL=index.js.map
